	--------------------------
	-- CHIPPER CHAT OPTIONS --
	--------------------------

local _, CC = ...
--	Below are the available options for ChipperChat, if you wish to change them.	
--	If you make extensive changes, I recommend saving a backup of this file.
--	When making changes while in-game, you will need to relog or reload your UI
--	for changes to take effect.


--	Editbox On Top
-------------------
--	available settings: true or false
--	if true, the editbox to enter your chat messages will be moved to above the chat frames
CC.editboxTop = true


--	Chat Tabs On Bottom
-----------------------
--	available settings: true or false
--	if true, the chat tabs will be moved to below the chat frames
CC.tabsBottom = false


--	Default Editbox Texture
---------------------------
--	available settings: true or false
--	if true, the normal editbox texture will be used instead of ChipperChat's
CC.editboxTexture = false


--	Enable Arrow Keys
---------------------
--	available settings: true or false
--	if true, you will not have to hold the Alt-key to navigate the editbox with the arrow keys
CC.enableArrowKeys = false


--	Hide Voice Chat Buttons		--ADD KEYBIND FOR CHANNELS WINDOW?
---------------------------
--	available settings: true or false
--	if true, the Chat Channels, Deafen Voice Chat, and Mute buttons next to the chat frame
--	will be hidden (deafen and mute are in the keybindings menu)
CC.hideVoiceChat = true


--	Control Time Stamps
-----------------------
--	available settings: true or false
--	if true, ChipperChat will control time stamps and disable the default UI's setting
--	time stamps will be shown for every message, including system messages and the combat log
--	note: time stamps will not be displayed for any message sent to chat prior to ChipperChat loading
CC.timeStamps = true


--	Time Stamp Format
---------------------
--	if ChipperChat is in charge of time stamps, what format to use
--	available settings:
--	"%I:%M"	(03:27)			"%I:%M:%S" (03:27:32)	"%I:%M:%S %p" (03:27:32 PM)
--	"%I:%M %p" (03:27 PM)	"%H:%M" (15:27)			"%H:%M:%S" (15:27:32)
CC.timeFormat = "%I:%M"


--	Sticky Channels
--------------------
--	available settings: 1 or 0
--	if set to 1, the editbox will remember that channel the next time you go to send a message
--	pre-3.3.5 behavior was that these were set to 0 - 3.3.5 made them sticky (1)
--	turning off sticky (0) removes the chance for an accidental mistell
CC.whisperSticky = 0		--normal whispers
CC.channelSticky = 0		--numbered chat channels (trade, etc.)
CC.BNwhisperSticky = 0		--battle.net RealID friends whispers


--	Chat History
-----------------
--	available settings: a number	(default UI is set to 128)
--	this is the number of lines saved when scrolling back through your chat window
--	a larger number means you can scroll back farther (careful not to pick something too large)
CC.chatHistory = 200


--	Control Toaster Frame	--all different in 8.0, currently disabled
--------------------------
--	available settings: true or false
--	if true, ChipperChat will take over anchoring of the Battle.net popup frame
--	if you have another addon to move this frame, then set this option to false
CC.moveToaster = true


--	Old DND and AFK Messages
-----------------------------
--	available settings: true or false
--	if true, the new IM-like messages of <Away> and <Busy> will be replaced with the old <AFK> and <DND>
CC.DND_AFK = true


--	Shorten Channel Names
--------------------------
--	available settings: true or false
--	if true, channel names will be abbreviated
--	(ex. [Guild] -> [G]  --or--  Seerah says,  -> Seerah:)
CC.shortChannels = true


--	Channel Nicknames
----------------------
--	available settings: a string (text in quotes "")
--	requires CC.shortChannels to be set to true
--	this is the text that will be shown instead of the longer channel names
--	key:  [pattern to look for] = [what to replace it with]
--	words in ALL CAPS on the left side will be replaced by the localized string (ie, should work for all languages)
CC.channelNicks = {

	--	Regular Channels
	---------------------
	--Guild chat
	[CHAT_MSG_GUILD] = "[G]",
	--Officer chat
	[CHAT_MSG_OFFICER] = "[O]",
	--Party chat
	[CHAT_MSG_PARTY] = "[P]",
	--Party leader
	[CHAT_MSG_PARTY_LEADER] = "[PL]",
	--Raid chat
	[CHAT_MSG_RAID] = "[R]",
	--Raid Leader
	[CHAT_MSG_RAID_LEADER] = "[RL]",
	--Raid Warning
	[CHAT_MSG_RAID_WARNING] = "[RW]",
	--Battleground chat
	[CHAT_MSG_BATTLEGROUND] = "[BG]",
	--Battleground leader
	[CHAT_MSG_BATTLEGROUND_LEADER] = "[BL]",
	--Instance chat
	[INSTANCE_CHAT] = "[I]",
	--Instance leader
	[INSTANCE_CHAT_LEADER] = "[IL]",
}

--ADVANCED OPTIONS--
CC.globalChannelNicks = {
	--	Numbered Channels
	----------------------
	--	Left side: "(%d+)%. " is looking for a number followed by a period and a space (ex. "3. ")
	--	Right side: %1 is replaced by whatever that number was
	--	% will also escape the period and brackets, so that those characters will display instead of using them as code in the regex.
	--	(ex. "%[%1%.Tr%]" --> "[3.Tr]")
	--	I couldn't find global strings for the other channels
	--	If you wish to shorten a custom channel, add it to the list below, following the others as a template
	--	If your locale is not English, substitute the channel names below (that aren't in CAPS) to those from your locale
	--	Any numbered channel that does not get matched to something on the left below, will just be [#.] (ex. "[3.]")

	--Trade chat
	["%[(%d+)%. "..TRADE..".-%]"] = "%[%1%.Tr%]",
	--General chat
	["%[(%d+)%. "..GENERAL..".-%]"] = "%[%1%.Gen%]",
	--Looking for group
	["%[(%d+)%. "..LOOKING..".-%]"] = "%[%1%.LFG%]",
	--WorldDefense
	["%[(%d+)%. WorldDefense%]"] = "%[%1%.WD%]",
	--LocalDefense
	["%[(%d+)%. LocalDefense%]"] = "%[%1%.LD%]",
	--GuildRecruitment
	["%[(%d+)%. GuildRecruitment%]"] = "%[%1%.GR%]",
	--All other numbered and custom channels
	["%[(%d+)%. .-%]"] = "%[%1%.%]",
--	["%[test%]"] = "123",
}
